@@ -1,6 +1,6 @@
 package Dancer2::Plugin::ParamTypes;
 # ABSTRACT: Parameter type checking plugin for Dancer2
-$Dancer2::Plugin::ParamTypes::VERSION = '0.002';
+$Dancer2::Plugin::ParamTypes::VERSION = '0.003';
 use strict;
 use warnings;
 
@@ -213,7 +213,7 @@ Dancer2::Plugin::ParamTypes - Parameter type checking plugin for Dancer2
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -287,7 +287,7 @@ First you must register a type check, allowing you to test stuff:
 
 C<with_types> defines checks for parameters for a route request.
 
-    get '/:name' => with_request [
+    get '/:name' => with_types [
 
         # Basic usage
         [ SOURCE, NAME, TYPE ]
@@ -374,7 +374,7 @@ Sawyer X
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Sawyer X.
+This software is Copyright (c) 2017 by Sawyer X.
 
 This is free software, licensed under:
 
